SystemOrganization addCategory: #'Glamour-Browsers'!

GLMImplicitBrowser subclass: #GLMAccumulator
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMAccumulator commentStamp: 'tg 2/2/2010 21:32' prior: 0!
An GLMAccumulator is an implicit type of browser that has the following behavior:
- each input entity has associated a pane without any relationship with the other panes
- based on the input entity if there already exists a pane associated, it is selected via GLMPaneSelected
- if there isnt a pane, a new pane is created
- based on entityToSelect, the associated pane is searched and potentially selected
- when a pane is selected in the user interface, the activeEntity is populated with the entity behind the selected pane

Input ports:
- entity
- entityToSelect

Output ports:
- selection
- activeEntity!

!GLMAccumulator methodsFor: 'accessing ports' stamp: 'tg 2/2/2010 22:03'!
activeEntity
	^ (self pane port: #activeEntity) value! !

!GLMAccumulator methodsFor: 'accessing ports' stamp: 'tg 2/2/2010 21:31'!
activeEntity: anObject
	^ (self pane port: #activeEntity) value: anObject ! !

!GLMAccumulator methodsFor: 'private' stamp: 'tg 8/22/2010 17:59'!
addPaneFrom: aPort 
	aPort value isNil ifTrue: [ ^ self ].
	(self tryToSelectPaneFrom: aPort) ifTrue: [ ^ self ].
	self panes addLast: (GLMPane in: self).
	GLMTransmission new
		ensureBundleStrategy;
		addActiveOrigin: aPort; 
		destination: (self panes last port: #entity); 
		presentations: (self presentations copy); 
		transmit.
	self announce: 
			(GLMPaneAdded 
				pane: self panes last 
				atPosition: self panes size 
				inBrowser: self)! !

!GLMAccumulator methodsFor: 'accessing ports' stamp: 'tg 2/2/2010 22:00'!
entityToSelect
	^ (self pane port: #entityToSelect) value! !

!GLMAccumulator methodsFor: 'accessing ports' stamp: 'tg 1/19/2010 21:24'!
entityToSelect: anObject
	^ (self pane port: #entityToSelect) value: anObject ! !

!GLMAccumulator methodsFor: 'events' stamp: 'tg 1/18/2010 07:47'!
innerPortEvent: aPortEvent 
	aPortEvent portName = #entity ifFalse: [
		"We don't want to resend the transmission, but use a new SimpleTransmission." 
		(self pane port: aPortEvent portName) value: aPortEvent value]! !

!GLMAccumulator methodsFor: 'events' stamp: 'cyrilledelaunay 3/29/2011 10:04'!
outerPortEvent: aPortEvent 
 	super outerPortEvent: aPortEvent.
	aPortEvent port name = #entityToSelect ifTrue: [
		self tryToSelectPaneFrom: aPortEvent port ].	
	aPortEvent port name = #entity ifTrue: [
		self addPaneFrom: aPortEvent port ]! !

!GLMAccumulator methodsFor: 'private' stamp: 'tg 1/31/2010 01:13'!
removePaneIndex: i
	| paneRemoved |
	paneRemoved := self panes removeAt: i.
	paneRemoved unregisterFromAllAnnouncements.
	self announce: (GLMPaneRemoved pane: paneRemoved fromBrowser: self )! !

!GLMAccumulator methodsFor: 'rendering' stamp: 'tg 1/18/2010 08:36'!
renderGlamorouslyOn: aRenderer
	^ aRenderer renderAccumulator: self! !

!GLMAccumulator methodsFor: 'private' stamp: 'tg 1/19/2010 21:50'!
tryToSelectPaneFrom: aPort
	self panes withIndexDo: [:each :i | 
		(each port: #entity) value = aPort value ifTrue: [
			self announce: 
				(GLMPaneSelected 
					pane: each 
					atPosition: i
					inBrowser: self).
			^ true ] ].
	^ false! !

GLMImplicitBrowser subclass: #GLMExpander
	instanceVariableNames: 'rootPane'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMExpander commentStamp: 'tg 5/1/2010 12:36' prior: 0!
GLMExpander aims to implement a Hopscotch-like browser!

!GLMExpander methodsFor: 'events' stamp: 'TudorGirba 1/2/2011 19:24'!
addPaneFrom: aPort 
	self panes addLast: (GLMPane in: self).
	GLMTransmission new
		ensureBundleStrategy;
		addActiveOrigin: aPort; 
		destination: (self panes last port: #entity); 
		presentations: (self presentations copy); 
		transmit.
	self announce: 
			(GLMPaneAdded 
				pane: self panes last 
				atPosition: self panes size 
				inBrowser: self)! !

!GLMExpander methodsFor: 'events' stamp: 'TudorGirba 1/9/2011 01:46'!
innerPortEvent: aPortEvent 
	 
	aPortEvent portName = #entity ifFalse: [
		"We resend the value to the outer pane"
		"We don't want to resend the transmission, but use a new SimpleTransmission." 
		(self pane port: aPortEvent portName) value: aPortEvent value]! !

!GLMExpander methodsFor: 'events' stamp: 'TudorGirba 1/9/2011 01:34'!
outerPortEvent: aPortEvent 
	 
	aPortEvent port name = #entity ifFalse: [^self]. 
	panes := nil. 
	self matches ifTrue: [
		"We only want to execute the transformation if the visibility condition matches"
		(self transformation glamourValue: aPortEvent port value) do: [:each |
			self addPaneFrom: (GLMSimplePort new value: each) ] ]! !

!GLMExpander methodsFor: 'rendering' stamp: 'TudorGirba 1/2/2011 18:59'!
renderGlamorouslyOn: aRenderer 
	^ aRenderer renderExpander: self! !

GLMImplicitBrowser subclass: #GLMFinder
	instanceVariableNames: 'hasFixedSizePanes fixedSizePanes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMFinder commentStamp: 'tg 1/26/2010 12:41' prior: 0!
A GLMFinder models a browsers that behaves like the Mac Finder: whenever the selection port is set on one pane, a new one is created to the right with the selection as entity. The Finder opens the first pane on the entity.

Input ports:
- entity: this is passed to the first pane

Output ports:
- selection: this port is populated with the value from the last selection port from one of the panes!

!GLMFinder methodsFor: 'private' stamp: 'TudorGirba 1/18/2011 14:35'!
addPaneFrom: aPort 
	self panes addLast: (GLMPane in: self).
	GLMTransmission new
		ensureBundleStrategy;
		addActiveOrigin: aPort; 
		destination: (self panes last port: #entity); 
		presentations: (self presentations copy); 
		transmit! !

!GLMFinder methodsFor: 'private' stamp: 'cyrilledelaunay 4/1/2011 16:23'!
addPaneFromInner: aPort 
	| newTransmission realTransmissions lastActivePresentation |
	"the lastActivePresentation is needed for knowing what presentation to show by default"
	self panes isEmpty ifFalse: [lastActivePresentation := self panes last lastActivePresentation ].
	self panes addLast: ( (GLMPane in: self) lastActivePresentation: lastActivePresentation; yourself).
	GLMTransmission new
		ensureBundleStrategy;
		addActiveOrigin: aPort; 
		destination: (self panes last port: #entity); 
		presentations: (self presentations copy); 
		transmit. 
	realTransmissions := self transmissions collect: [:each |  
			newTransmission := GLMTransmission new ensureBundleStrategy. 
			each activeOrigins do: [:eachPort | 
				newTransmission addActiveOrigin: (aPort pane port: eachPort name)]. 
			each passiveOrigins do: [:eachPort | 
				newTransmission addPassiveOrigin: (aPort pane port: eachPort name)]. 
			newTransmission 
				destination: (self panes last port: #entity); 
				addPresentations: (self presentations collect: #copy);
				addPresentations: (each presentations collect: #copy)] . 
	(realTransmissions select: [:each | each originatesAt: aPort]) 
		do: [:each | each transmit]. ! !

!GLMFinder methodsFor: 'accessing' stamp: 'TudorGirba 1/26/2011 10:59'!
hasFixedSizePanes
	^ hasFixedSizePanes ifNil: [hasFixedSizePanes := true]! !

!GLMFinder methodsFor: 'accessing' stamp: 'TudorGirba 1/26/2011 10:59'!
hasFixedSizePanes: aBoolean
	hasFixedSizePanes := aBoolean! !

!GLMFinder methodsFor: 'events' stamp: 'tg 9/13/2010 19:25'!
innerPortEvent: aPortEvent 
	aPortEvent portName = #entity ifFalse: [
		"We don't want to resend the transmission, but use a new SimpleTransmission." 
		(self pane port: aPortEvent portName) value: aPortEvent value]. 

	aPortEvent port name = #selection ifTrue: [
		| index toReplace |
		index := self panes reversed indexOf: aPortEvent pane.
		(self panes reversed first: index - 2) do: [ :each |  
			self removeLastPane.
			self announce: (GLMPaneRemoved pane: each fromBrowser: self) ].
		index <= 1 
			ifTrue: [ 
				self addPaneFromInner: aPortEvent port.
				self announce: 
					(GLMPaneAdded 
						pane: self panes last 
						atPosition: self panes size 
						inBrowser: self) ]
			ifFalse: [
				toReplace := self removeLastPane.
				self addPaneFromInner: aPortEvent port.
				self announce: (GLMPaneReplaced 
							oldPane: toReplace 
							newPane: self panes last
							fromBrowser: self ) ] 
	]! !

!GLMFinder methodsFor: 'events' stamp: 'TudorGirba 1/18/2011 14:35'!
outerPortEvent: aPortEvent 
	 
	| toReplace |
	aPortEvent port name = #entity ifFalse: [^self]. 
	self panes isEmpty
		ifFalse: [
			toReplace := self panes first.
			"self removeAllPanes."
			panes := nil.
			self addPaneFrom: aPortEvent port.
			self announce: (GLMPaneReplaced 
						oldPane: toReplace 
						newPane: self panes first
						fromBrowser: self ) ]
		ifTrue: [
			self addPaneFrom: aPortEvent port.
			self announce: 
				(GLMPaneAdded 
					pane: self panes last 
					atPosition: self panes size 
					inBrowser: self)]! !

!GLMFinder methodsFor: 'rendering' stamp: 'TudorGirba 1/2/2011 18:59'!
renderGlamorouslyOn: aRenderer 
	^ aRenderer renderFinder: self! !

GLMImplicitBrowser subclass: #GLMValidator
	instanceVariableNames: 'hasFixedSizePanes fixedSizePanes buttonActions'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMValidator classSide methodsFor: 'examples' stamp: 'cyrilledelaunay 3/30/2011 10:41'!
example

	"self example"
	| finder validator |
	finder := GLMFinder new.
	validator := GLMValidator new.
	validator validator: 'Ok' act: [:x | ].
	validator show: [:a | a list display: [:x | 1 to: x ]].
	finder show: [:a |
 	      a custom: validator].
	finder openOn: 100! !

!GLMValidator classSide methodsFor: 'examples' stamp: 'cyrilledelaunay 4/1/2011 16:03'!
exampleDynamic

	"self exampleDynamic"
	| finder validator |
	finder := GLMFinder new.
	validator := GLMValidator new.
	validator validator: 'Ok' act: [:x | ].
	validator show: [:a | 
		a dynamic display: [:collection |
			GLMListPresentation new display: [:tmp | collection]
			]  
		].
	validator openOn: #(1 2 3 4)! !

!GLMValidator methodsFor: 'accessing' stamp: 'cyrilledelaunay 3/23/2011 13:04'!
addButtonAction: aGLMGenericAction

	self buttonActions addLast: aGLMGenericAction ! !

!GLMValidator methodsFor: 'private' stamp: 'cyrilledelaunay 3/29/2011 10:11'!
addPaneFrom: aPort 

	self panes isEmpty ifTrue: [
		self panes addLast: (GLMPane in: self).
		GLMTransmission new
			ensureBundleStrategy;
			addActiveOrigin: aPort; 
			destination: (self panes last port: #entity); 
			presentations: (self presentations copy); 
			transmit
		]
	! !

!GLMValidator methodsFor: 'private' stamp: 'cyrilledelaunay 3/23/2011 11:40'!
addPaneFromInner: aPort 
	| newTransmission realTransmissions lastActivePresentation |
	"the lastActivePresentation is needed for knowing what presentation to show by default"
	self panes isEmpty ifFalse: [lastActivePresentation := self panes last lastActivePresentation ].
	self panes addLast: ( (GLMPane in: self) lastActivePresentation: lastActivePresentation; yourself).
	GLMTransmission new
		ensureBundleStrategy;
		addActiveOrigin: aPort; 
		destination: (self panes last port: #entity); 
		presentations: (self presentations copy); 
		transmit. 
	realTransmissions := self transmissions collect: [:each |  
			newTransmission := GLMTransmission new ensureBundleStrategy. 
			each activeOrigins do: [:eachPort | 
				newTransmission addActiveOrigin: (aPort pane port: eachPort name)]. 
			each passiveOrigins do: [:eachPort | 
				newTransmission addPassiveOrigin: (aPort pane port: eachPort name)]. 
			newTransmission 
				destination: (self panes last port: #entity); 
				addPresentations: (self presentations collect: #copy);
				addPresentations: (each presentations collect: #copy)] . 
	(realTransmissions select: [:each | each originatesAt: aPort]) 
		do: [:each | each transmit]. ! !

!GLMValidator methodsFor: 'accessing' stamp: 'cyrilledelaunay 3/23/2011 13:00'!
buttonActions

	^ buttonActions! !

!GLMValidator methodsFor: 'events' stamp: 'cyrilledelaunay 4/8/2011 12:19'!
close

	self announce: (GLMBrowserClosed new)! !

!GLMValidator methodsFor: 'events' stamp: 'cyrilledelaunay 3/31/2011 13:53'!
explicitlyInnerPortNamed: aPortName .  

	aPortName = #entity ifFalse: [
		self panes first ports do: [:each | (self pane port: each name) value: each value]
		]! !

!GLMValidator methodsFor: 'initialize-release' stamp: 'cyrilledelaunay 3/23/2011 13:20'!
initialize

	super initialize.
	buttonActions := OrderedCollection new! !

!GLMValidator methodsFor: 'events' stamp: 'cyrilledelaunay 3/31/2011 13:57'!
innerPortEvent: aPortEvent 

! !

!GLMValidator methodsFor: 'events' stamp: 'cyrilledelaunay 3/30/2011 10:35'!
outerPortEvent: aPortEvent 
	
 	super outerPortEvent: aPortEvent.
	aPortEvent port name = #entityToSelect ifTrue: [
		self tryToSelectPaneFrom: aPortEvent port ].	
	aPortEvent port name = #entity ifTrue: [
		self addPaneFrom: aPortEvent port ]! !

!GLMValidator methodsFor: 'rendering' stamp: 'cyrilledelaunay 4/8/2011 12:20'!
renderGlamorouslyOn: aRenderer 

	self on: GLMBrowserClosed send: #actOnWizardClosed: to: aRenderer.
	^ aRenderer renderValidator: self! !

!GLMValidator methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 15:33'!
validator: aString act: aBlock 

	"will populate all ports by default at the end"
	self addButtonAction:   
			((GLMGenericAction new) 
				action: [:tmpBrowser |
					
					tmpBrowser panes first ports do: [:aPort |
						tmpBrowser explicitlyInnerPortNamed: aPort name
						].
					aBlock value: tmpBrowser.
					]; 
				title: aString; 
				yourself).
				! !

!GLMValidator methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 15:33'!
validator: aString act: aBlock populatePorts: aCollectionOfPorts

	self addButtonAction:   
			((GLMGenericAction new) 
				action: [:tmpBrowser |
					
					aCollectionOfPorts do: [:aSymbol |
						tmpBrowser explicitlyInnerPortNamed: aSymbol.  
 						].
					aBlock value: tmpBrowser.
					]; 
				title: aString; 
				yourself).
				
	! !

!GLMValidator methodsFor: 'accessing' stamp: 'cyrilledelaunay 3/31/2011 13:56'!
validator: aString populatePorts: aCollectionOfPorts

	self addButtonAction:   
			((GLMGenericAction new) 
				action: [:tmpBrowser |
					aCollectionOfPorts do: [:aSymbol |
						tmpBrowser explicitlyInnerPortNamed: aSymbol.  
 						]
					]; 
				title: aString; 
				yourself).
				
	! !

GLMImplicitBrowser subclass: #GLMWizard
	instanceVariableNames: 'wizardSize steps genericStep currentIndex terminateButtonAction previousButtonAction nextButtonAction cancelButtonAction specificAnnouncementActions externalCancelButtonAction externalNextButtonAction externalPreviousButtonAction externalTerminateButtonAction stepsDictionary stepsAndPanes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMWizard classSide methodsFor: 'examples' stamp: 'cyrilledelaunay 4/4/2011 14:11'!
genericStepWithGenericSizeExample

	"self genericStepWithGenericSizeExample"
	| wizard |
	wizard := GLMWizard new.
	(wizard genericStep: #step)
		show: [:a | 
		a list
			display: [:aNumber | 1 to: aNumber] 
		] ;
		name: 'Wizard pane';
		size: [:aNumber | aNumber].
	wizard openOn: 4.
! !

!GLMWizard classSide methodsFor: 'examples' stamp: 'cyrilledelaunay 4/4/2011 13:59'!
linkedStepsExample

	"self linkedStepsExample"
	| wizard |
	wizard := GLMWizard new.
	(wizard step: #step1) 
		show: [:a |
			a list
				display: [:aList |
					aList
					].
			];
		name: 'first pane'
		.
	(wizard step: #step2) 
		from: #step1; 
		show: [:a |
			a list
				display: [:aNumber |
					1 to: aNumber
					]
			];
		name: 'second pane'.
	wizard openOn: (1 to: 100).
! !

!GLMWizard classSide methodsFor: 'examples' stamp: 'cyrilledelaunay 4/4/2011 13:52'!
simpleExample

	"self simpleExample"
	| wizard |
	wizard := GLMWizard new.
	(wizard genericStep: #step)
		show: [:a | 
		a list
			display: [:list | list] 
		] ;
		name: 'Wizard pane';
		size: 2.
	wizard openOn: (1 to: 100).
! !

!GLMWizard methodsFor: 'private' stamp: 'cyrilledelaunay 4/4/2011 11:13'!
addPaneFrom: aPort 
	self panes addLast: self computePane.
	GLMTransmission new
		ensureBundleStrategy;
		addActiveOrigin: aPort; 
		destination: (self panes last port: #entity); 
		presentations: (self presentations copy); 
		transmit! !

!GLMWizard methodsFor: 'testing' stamp: 'cyrilledelaunay 4/4/2011 13:33'!
atBeginning

	^ self currentIndex = 1 and: [
		self stepToUse atBeginning
		]! !

!GLMWizard methodsFor: 'testing' stamp: 'cyrilledelaunay 4/4/2011 13:32'!
atEnd

	^ self currentIndex = self steps size and: [
		self stepToUse atEnd
		]! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 4/1/2011 14:04'!
backSign
	^ '<< Back'! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 14:24'!
cancelButtonAction

	self externalCancelButtonAction value: self entity.
	self announce: (GLMBrowserClosed new)		! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 3/31/2011 15:46'!
computeFirstPaneValidator

	|tmpValidator|
	tmpValidator := self computePaneValidator.
	self setFirstPaneButtonsTo: tmpValidator.
	^ tmpValidator  
! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 3/31/2011 15:46'!
computeLastPaneValidator

	|tmpValidator|
	tmpValidator := self computePaneValidator.
	self setLastPaneButtonsTo: tmpValidator.
	^ tmpValidator  
! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 3/31/2011 15:47'!
computeMiddlePaneValidator

	|tmpValidator|
	tmpValidator := self computePaneValidator.
	self setMiddlePaneButtonsTo: tmpValidator.
	^ tmpValidator  
! !

!GLMWizard methodsFor: 'building pane' stamp: 'cyrilledelaunay 4/4/2011 14:35'!
computePane

	self hasUniquePane ifTrue: [^ self computePaneWith: self computeSinglePaneValidator].
	self atBeginning ifTrue: [^ self computePaneWith: self computeFirstPaneValidator].
	self atEnd ifTrue: [^ self computePaneWith: self computeLastPaneValidator].
	^( self computePaneWith: self computeMiddlePaneValidator).
	
! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 4/4/2011 15:18'!
computePaneValidator

	|tmpPresentation tmpValidator|
	tmpPresentation := (self stepToUse presentationBlock moValue: self).
	tmpValidator := GLMValidator new.
	tmpValidator show: [:a | a custom: tmpPresentation]. 
	"tmpValidator startOn: self entity."
	^ tmpValidator 
! !

!GLMWizard methodsFor: 'building pane' stamp: 'cyrilledelaunay 4/4/2011 15:45'!
computePaneWith: aValidator

	|tmpPane|
	tmpPane := GLMPane in: self.
	tmpPane addPresentation: aValidator.
	(tmpPane port: #entity) value:  self stepToUse input.
	self title: self stepToUse name.
	^ tmpPane ! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 3/31/2011 17:12'!
computeSinglePaneValidator

	|tmpValidator|
	tmpValidator := self computePaneValidator.
	self setSinglePaneButtonsTo: tmpValidator.
	^ tmpValidator  
! !

!GLMWizard methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 16:15'!
currentIndex

	^ currentIndex ifNil: [currentIndex := 1]! !

!GLMWizard methodsFor: 'accessing' stamp: 'cyrilledelaunay 3/31/2011 14:56'!
currentIndex: anInteger

	currentIndex := anInteger! !

!GLMWizard methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 16:01'!
currentStep 

	^ self steps at: self currentIndex! !

!GLMWizard methodsFor: 'accessing - scripting' stamp: 'cyrilledelaunay 4/4/2011 14:21'!
defaultStepName

	^'default_step_name'! !

!GLMWizard methodsFor: 'accessing ports' stamp: 'cyrilledelaunay 4/4/2011 15:47'!
entity: anObject

	super entity: anObject.
	self updateWhenNext! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:56'!
externalCancelButtonAction

	^ externalCancelButtonAction ifNil: [externalCancelButtonAction := [:input | ]]! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:41'!
externalCancelButtonAction: aBlock

	externalCancelButtonAction := aBlock! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:55'!
externalNextButtonAction

	^ externalNextButtonAction ifNil: [externalNextButtonAction := [:input | ]]! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:42'!
externalNextButtonAction: aBlock

	externalNextButtonAction := aBlock ! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:55'!
externalPreviousButtonAction

	^ externalPreviousButtonAction ifNil: [externalPreviousButtonAction := [:input | ]]! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:43'!
externalPreviousButtonAction: aBlock

	externalPreviousButtonAction := aBlock! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:54'!
externalTerminateButtonAction

	^ externalTerminateButtonAction ifNil: [externalTerminateButtonAction := [:input | ]]! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:58'!
externalTerminateButtonAction: aBlock

	externalTerminateButtonAction := aBlock! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 3/31/2011 16:17'!
forwardSign
	^ 'Next >>'! !

!GLMWizard methodsFor: 'accessing - scripting' stamp: 'cyrilledelaunay 4/4/2011 14:23'!
genericStep

	|tmpSymbol|
	tmpSymbol := (self defaultStepName, self steps size asString) asSymbol.
	self steps add: tmpSymbol.
	^ self stepsDictionary at: tmpSymbol put: GLMWizardGenericStep new.! !

!GLMWizard methodsFor: 'accessing - scripting' stamp: 'cyrilledelaunay 4/4/2011 13:15'!
genericStep: aSymbol 

	self steps add: (aSymbol).
	^ self stepsDictionary at: aSymbol put: GLMWizardGenericStep new.! !

!GLMWizard methodsFor: 'testing' stamp: 'cyrilledelaunay 4/4/2011 13:49'!
hasUniquePane

	^ self steps size = 1 and: [self stepToUse size = 1]! !

!GLMWizard methodsFor: 'initialize-release' stamp: 'cyrilledelaunay 4/1/2011 15:41'!
initialize

	super initialize.
	scriptTransmission := GLMTransmission new.! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:59'!
nextButtonAction

		self externalNextButtonAction value: self entity.
		self updateWhenNext ! !

!GLMWizard methodsFor: 'building pane' stamp: 'cyrilledelaunay 4/4/2011 16:22'!
notifyAndAddNewPane: aGLMPane

	|oldPane   tmpPanes|
	tmpPanes := self stepsAndPanes at: self currentStep ifAbsentPut: [OrderedCollection new].
	tmpPanes addLast: aGLMPane.  
	"self panes addLast: aGLMPane".
	self announce: (GLMPaneAdded new
							pane: aGLMPane;
							browser: self;
							yourself ) 
	! !

!GLMWizard methodsFor: 'building pane' stamp: 'cyrilledelaunay 4/4/2011 16:47'!
notifyAndRemoveCurrentPane

	|oldPane   tmpPanes|
	tmpPanes := self stepsAndPanes at: self currentStep ifAbsentPut: [OrderedCollection new].
	oldPane :=  tmpPanes last.
	tmpPanes removeLast.
	self announce: (GLMPaneRemoved new
							pane: oldPane;
							browser: self;
							yourself ) 
	! !

!GLMWizard methodsFor: 'building pane' stamp: 'cyrilledelaunay 4/4/2011 16:22'!
notifyAndSetAsCurrentPane: aGLMPane

	|oldPane   tmpPanes|
	tmpPanes := self stepsAndPanes at: self currentStep ifAbsentPut: [OrderedCollection new].
	tmpPanes removeLast.
	tmpPanes addLast: aGLMPane.
	"self panes addLast: aGLMPane. " 
	self announce: (GLMPaneReplaced 
							oldPane: oldPane 
							newPane: tmpPanes last
							fromBrowser: self ) 
	! !

!GLMWizard methodsFor: 'announcements' stamp: 'cyrilledelaunay 4/1/2011 10:37'!
on: anAnnouncementClass send: aSelector

	self specificAnnouncementActions at: anAnnouncementClass  put: aSelector ! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:57'!
onCancelDo: aBlock

	self externalCancelButtonAction: aBlock! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:58'!
onNextDo: aBlock

	self externalNextButtonAction: aBlock! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:58'!
onPreviousDo: aBlock

	self externalPreviousButtonAction: aBlock! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 13:58'!
onTerminateDo: aBlock

	self externalTerminateButtonAction: aBlock! !

!GLMWizard methodsFor: 'events' stamp: 'cyrilledelaunay 4/5/2011 14:35'!
populateInputOfStep: aGLMWiizardStep

	self stepToUse previousStep isNil
		ifTrue: [
			self stepToUse input: (self pane port: #entity) value.
			]
		ifFalse: [
			self stepToUse input: ((self stepsAndPanes at: self stepToUse previousStep) last port: #selection) value.
			].
	
			! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 14:01'!
previousButtonAction

		self externalPreviousButtonAction value: self entity.
		self updateWhenPrevious
		! !

!GLMWizard methodsFor: 'rendering' stamp: 'cyrilledelaunay 4/1/2011 14:25'!
renderGlamorouslyOn: aRenderer 
 
	self on: GLMBrowserClosed send: #actOnWizardClosed: to: aRenderer.
	^ aRenderer renderWizard: self! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 4/1/2011 14:04'!
setFirstPaneButtonsTo: aValidator

	aValidator validator: 'Cancel' act:  [:input |
		self cancelButtonAction
		] .
	aValidator validator: self forwardSign act: [:input |
		self nextButtonAction 
		] populatePorts: #(#selection).! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 4/1/2011 14:03'!
setLastPaneButtonsTo: aValidator

	aValidator validator:  'Cancel' act:  [:input |
		self cancelButtonAction
		].
	aValidator validator: self backSign act: [:input |
		self previousButtonAction
		].
	aValidator validator: 'Terminate' act:  [:input |
		self terminateButtonAction
		].! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 4/1/2011 14:02'!
setMiddlePaneButtonsTo: aValidator

	aValidator validator: 'Cancel' act: [:input |
		self cancelButtonAction 
		].
	aValidator validator: self backSign act: [:input |
		self previousButtonAction
		].
	aValidator validator: self forwardSign act: [:input |
		self nextButtonAction
		].
	! !

!GLMWizard methodsFor: 'building internal' stamp: 'cyrilledelaunay 4/1/2011 14:02'!
setSinglePaneButtonsTo: aValidator

	aValidator validator: 'Cancel' act: [:input |
		self cancelButtonAction
		].
	aValidator validator: 'Terminate' act: [:input |
		self terminateButtonAction
		].
	! !

!GLMWizard methodsFor: 'announcements' stamp: 'cyrilledelaunay 4/1/2011 10:37'!
setSpecificAnnouncementActionsTo: aRenderer

	self specificAnnouncementActions keysAndValuesDo: [:anAnnouncementClass :aSymbol |
		self on: anAnnouncementClass send: aSymbol to: aRenderer.
		]! !

!GLMWizard methodsFor: 'announcements' stamp: 'cyrilledelaunay 4/1/2011 10:36'!
specificAnnouncementActions

	^ specificAnnouncementActions ifNil: [specificAnnouncementActions := Dictionary new]! !

!GLMWizard methodsFor: 'accessing - scripting' stamp: 'cyrilledelaunay 4/4/2011 14:22'!
step


	|tmpSymbol|
	tmpSymbol := (self defaultStepName, self steps size asString) asSymbol.
	self steps add: tmpSymbol.
	^ self stepsDictionary at: tmpSymbol put: GLMWizardStep new.! !

!GLMWizard methodsFor: 'accessing - scripting' stamp: 'cyrilledelaunay 4/4/2011 13:14'!
step: aSymbol 

	self steps add: (aSymbol).
	^ self stepsDictionary at: aSymbol put: GLMWizardStep new.! !

!GLMWizard methodsFor: 'private' stamp: 'cyrilledelaunay 4/4/2011 13:48'!
stepToUse

	^ self stepsDictionary at: (self steps at: self currentIndex) 
		! !

!GLMWizard methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/1/2011 12:37'!
steps

	^ steps ifNil: [steps := OrderedCollection new]! !

!GLMWizard methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 14:59'!
stepsAndPanes

	^ stepsAndPanes ifNil: [stepsAndPanes := Dictionary new]! !

!GLMWizard methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 14:58'!
stepsAndPanesDictionary

	^ stepsDictionary ifNil: [stepsDictionary := Dictionary new]! !

!GLMWizard methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 13:16'!
stepsDictionary

	^ stepsDictionary ifNil: [stepsDictionary := Dictionary new]! !

!GLMWizard methodsFor: 'accessing - buttons actions ' stamp: 'cyrilledelaunay 4/1/2011 14:24'!
terminateButtonAction

	self externalTerminateButtonAction value: self entity.
	self announce: (GLMBrowserClosed new)
		! !

!GLMWizard methodsFor: 'events' stamp: 'cyrilledelaunay 4/1/2011 11:52'!
updatePane

	|tmpPane|
	self notifyAndSetAsCurrentPane: self computePane.! !

!GLMWizard methodsFor: 'events' stamp: 'cyrilledelaunay 4/5/2011 14:37'!
updateWhenNext

	|tmpPane|
	self populateInputOfStep: self stepToUse.  
	self stepToUse atEnd
		ifTrue: [
			self currentIndex: self currentIndex + 1.
			self populateInputOfStep: self stepToUse.  
			].
	self stepToUse incrementNumberOfDisplay.
	tmpPane := self computePane.
	self notifyAndAddNewPane: self computePane.! !

!GLMWizard methodsFor: 'events' stamp: 'cyrilledelaunay 4/5/2011 12:11'!
updateWhenPrevious

	|tmpPane|
	self notifyAndRemoveCurrentPane.
	self stepToUse atBeginning 
		ifTrue: [
			self stepToUse decrementNumberOfDisplay.
			self currentIndex: self currentIndex - 1]
		ifFalse: [
			self stepToUse decrementNumberOfDisplay.
			].
	self stepToUse input: self entity.
	self notifyAndSetAsCurrentPane: (self stepsAndPanes at: self currentStep) last .! !

!GLMWizard methodsFor: 'private' stamp: 'cyrilledelaunay 3/31/2011 16:08'!
valueOf: anObject

	^ anObject moValue: (self pane port: #entity) value! !

Announcement subclass: #GLMBrowserClosed
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

Announcement subclass: #GLMPaneAnnouncement
	instanceVariableNames: 'pane browser position'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMPaneAnnouncement commentStamp: 'TudorGirba 2/4/2011 21:24' prior: 0!
These announcements are used by the browser to communicate with the renderer whenever the panes configuration is modified in some way.

Instance Variables:
	pane	<GLMPane>
	browser	<GLMBrowser>
	position	<Integer>!

GLMPaneAnnouncement subclass: #GLMPaneAdded
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMPaneAnnouncement classSide methodsFor: 'instance creation' stamp: 'tg 1/18/2010 11:08'!
pane: aPane atPosition: anInteger inBrowser: aBrowser 
	 
	^(self new) 
		pane: aPane; 
		position: anInteger; 
		browser: aBrowser; 
		yourself! !

!GLMPaneAnnouncement methodsFor: 'accessing' stamp: 'tg 1/18/2010 11:06'!
browser 
	 
	^browser! !

!GLMPaneAnnouncement methodsFor: 'accessing' stamp: 'tg 1/18/2010 11:06'!
browser: anObject 
	 
	browser := anObject! !

!GLMPaneAnnouncement methodsFor: 'accessing' stamp: 'tg 1/18/2010 11:06'!
pane 
	 
	^pane! !

!GLMPaneAnnouncement methodsFor: 'accessing' stamp: 'tg 1/18/2010 11:06'!
pane: anObject 
	 
	pane := anObject! !

!GLMPaneAnnouncement methodsFor: 'accessing' stamp: 'tg 1/18/2010 11:06'!
position 
	 
	^position! !

!GLMPaneAnnouncement methodsFor: 'accessing' stamp: 'tg 1/18/2010 11:06'!
position: anObject 
	 
	position := anObject! !

GLMPaneAnnouncement subclass: #GLMPaneRemoved
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMPaneRemoved classSide methodsFor: 'instance creation' stamp: ' 4/5/09 22:18'!
pane: aPane fromBrowser: aBrowser 
	 
	^(self new) 
		pane: aPane; 
		browser: aBrowser; 
		yourself! !

GLMPaneAnnouncement subclass: #GLMPaneReplaced
	instanceVariableNames: 'oldPane newPane'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMPaneReplaced classSide methodsFor: 'as yet unclassified' stamp: 'tg 8/22/2010 21:35'!
oldPane: oldPane newPane: newPane fromBrowser: aBrowser
	^ self new 
		oldPane: oldPane;
		newPane: newPane;
		browser: aBrowser! !

!GLMPaneReplaced methodsFor: 'accessing' stamp: 'tg 8/22/2010 21:36'!
newPane
	^ newPane! !

!GLMPaneReplaced methodsFor: 'accessing' stamp: 'tg 8/22/2010 21:36'!
newPane: anObject
	newPane := anObject! !

!GLMPaneReplaced methodsFor: 'accessing' stamp: 'tg 8/22/2010 21:36'!
oldPane
	^ oldPane! !

!GLMPaneReplaced methodsFor: 'accessing' stamp: 'tg 8/22/2010 21:36'!
oldPane: anObject
	oldPane := anObject! !

GLMPaneAnnouncement subclass: #GLMPaneSelected
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

GLMExplicitBrowser subclass: #GLMStacker
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMStacker commentStamp: '<historical>' prior: 0!
A GLMStacker is an explicit browser that allows us to stack panes on top of each other and show them as tabs.!

!GLMStacker methodsFor: 'as yet unclassified' stamp: 'tg 6/12/2010 14:21'!
aPane: aBlockOrSymbol
	^ self addNewPaneNamed: aBlockOrSymbol! !

!GLMStacker methodsFor: 'as yet unclassified' stamp: 'tg 6/12/2010 14:18'!
renderGlamorouslyOn: aRenderer 
	^aRenderer renderStacker: self! !

GLMExplicitBrowser subclass: #GLMTabulator
	instanceVariableNames: 'cell'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMTabulator commentStamp: '<historical>' prior: 0!
A GLMTabulator is an explicit browser that allows us to place panes in columns and rows.!

!GLMTabulator methodsFor: 'layout' stamp: ' 4/5/09 22:18'!
addColumn: aBlockOrSymbol 
	 
	^self cellOrRow addColumn: aBlockOrSymbol! !

!GLMTabulator methodsFor: 'layout' stamp: 'tg 10/22/2009 13:27'!
addColumn: aBlockOrSymbol size: anInteger 
	 
	^(self addColumn: aBlockOrSymbol) size: anInteger; span: 0! !

!GLMTabulator methodsFor: 'layout' stamp: ' 4/5/09 22:18'!
addColumn: aBlockOrSymbol span: anInteger 
	 
	^(self addColumn: aBlockOrSymbol) span: anInteger! !

!GLMTabulator methodsFor: 'layout' stamp: ' 4/5/09 22:18'!
addRow: aBlockOrSymbol 
	 
	^self cellOrColumn addRow: aBlockOrSymbol! !

!GLMTabulator methodsFor: 'layout' stamp: 'tg 10/22/2009 13:27'!
addRow: aBlockOrSymbol size: anInteger 
	 
	^(self addRow: aBlockOrSymbol) size: anInteger; span: 0! !

!GLMTabulator methodsFor: 'layout' stamp: ' 4/5/09 22:18'!
addRow: aBlockOrSymbol span: anInteger 
	 
	^(self addRow: aBlockOrSymbol) span: anInteger! !

!GLMTabulator methodsFor: 'layout' stamp: ' 4/5/09 22:18'!
cell 
	 
	^cell! !

!GLMTabulator methodsFor: 'private' stamp: ' 4/5/09 22:18'!
cellOrColumn 
	 
	^cell ifNil: [cell := GLMCustomColumn new browser: self]! !

!GLMTabulator methodsFor: 'private' stamp: ' 4/5/09 22:18'!
cellOrRow 
	 
	^cell ifNil: [cell := GLMCustomRow new browser: self]! !

!GLMTabulator methodsFor: 'rendering' stamp: 'tg 1/10/2010 16:20'!
renderGlamorouslyOn: aRenderer 
	 
	^aRenderer renderTabulator: self! !

Object subclass: #GLMAbstractWizardStep
	instanceVariableNames: 'name presentationBlock previousStep numberOfDisplay input'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMAbstractWizardStep methodsFor: 'testing' stamp: 'cyrilledelaunay 4/4/2011 13:57'!
atBeginning 

	^ self numberOfDisplay = 1! !

!GLMAbstractWizardStep methodsFor: 'testing' stamp: 'cyrilledelaunay 4/4/2011 17:10'!
atEnd

	^ self size = self numberOfDisplay ! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 13:43'!
decrementNumberOfDisplay 

	self numberOfDisplay: self numberOfDisplay - 1! !

!GLMAbstractWizardStep methodsFor: 'scripting' stamp: 'cyrilledelaunay 4/4/2011 13:17'!
from: aSymbol

	self previousStep: aSymbol  ! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 13:43'!
incrementNumberOfDisplay

	self numberOfDisplay: self numberOfDisplay + 1! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 14:00'!
input

	^ input ! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 14:01'!
input: anObject

	input := anObject! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 13:07'!
name

	^ name ifNil: [name := '']! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 12:02'!
name: aSymbolOrABlock

	name := aSymbolOrABlock! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 13:07'!
numberOfDisplay
	
	^ numberOfDisplay ifNil: [numberOfDisplay := 0]! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 13:06'!
numberOfDisplay: aNumber
	
	numberOfDisplay := aNumber! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 12:02'!
presentationBlock

	^ presentationBlock ! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 12:02'!
presentationBlock: aBlock

	presentationBlock :=  aBlock! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 12:02'!
previousStep

	^ previousStep! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 12:02'!
previousStep: aSymbol

	previousStep := aSymbol! !

!GLMAbstractWizardStep methodsFor: 'scripting' stamp: 'cyrilledelaunay 4/4/2011 13:16'!
show: aBlock

	self presentationBlock: aBlock  ! !

!GLMAbstractWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 12:03'!
size

	^ self subclassResponsibility ! !

GLMAbstractWizardStep subclass: #GLMWizardGenericStep
	instanceVariableNames: 'size'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMWizardGenericStep methodsFor: 'initialize-release' stamp: 'cyrilledelaunay 4/4/2011 13:51'!
initialize

	super initialize.
	size := 1! !

!GLMWizardGenericStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 15:26'!
size

	^ size moValue: self input! !

!GLMWizardGenericStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 12:06'!
size: aNumberOrAblock

	size := aNumberOrAblock ! !

GLMAbstractWizardStep subclass: #GLMWizardStep
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMWizardStep methodsFor: 'accessing' stamp: 'cyrilledelaunay 4/4/2011 12:04'!
size

	^ 1! !

Object subclass: #GLMCustomCell
	instanceVariableNames: 'children span id browser size'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMCustomCell methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
browser 
	 
	^browser! !

!GLMCustomCell methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
browser: anObject 
	 
	browser := anObject! !

!GLMCustomCell methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
children 
	 
	^children ifNil: [children := OrderedCollection new]! !

!GLMCustomCell methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
children: anObject 
	 
	children := anObject! !

!GLMCustomCell methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
childrenCount 
	 
	^self children 
		inject: 0 
		into: [:sum :each | sum + each span]! !

!GLMCustomCell methodsFor: 'testing' stamp: ' 4/5/09 22:18'!
hasId 
	 
	^id notNil! !

!GLMCustomCell methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
id 
	 
	^id ifNil: [#anonymous]! !

!GLMCustomCell methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
id: anObject 
	 
	id := anObject! !

!GLMCustomCell methodsFor: 'testing' stamp: ' 4/5/09 22:18'!
isColumn 
	 
	^false! !

!GLMCustomCell methodsFor: 'testing' stamp: ' 4/5/09 22:18'!
isRow 
	 
	^false! !

!GLMCustomCell methodsFor: 'testing' stamp: ' 4/5/09 22:18'!
isSplitIntoColumns 
	 
	^self children allSatisfy: [:each | each isColumn]! !

!GLMCustomCell methodsFor: 'testing' stamp: ' 4/5/09 22:18'!
isSplitIntoRows 
	 
	^self children allSatisfy: [:each | each isRow]! !

!GLMCustomCell methodsFor: 'accessing' stamp: 'tg 10/22/2009 10:17'!
size
	^ size ifNil: [0]! !

!GLMCustomCell methodsFor: 'accessing' stamp: 'tg 10/22/2009 10:20'!
size: anObject
	size := anObject.! !

!GLMCustomCell methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
span 
	 
	^span ifNil: [span := 1]! !

!GLMCustomCell methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
span: anObject 
	 
	span := anObject! !

GLMCustomCell subclass: #GLMCustomColumn
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMCustomColumn methodsFor: 'accessing' stamp: 'jorge.ressia 6/2/2009 21:53'!
addRow: aBlockOrSymbol 
	 
	| newRow cell | 
	cell := aBlockOrSymbol isSymbol 
		ifTrue: 
			[self browser 
				addNewPaneNamed: aBlockOrSymbol. 
			(GLMCustomRow new) 
				id: aBlockOrSymbol; 
				browser: self browser] 
		ifFalse: 
			[newRow := GLMCustomRow new browser: self browser. 
			aBlockOrSymbol value: newRow. 
			newRow]. 
	self children addLast: cell. 
	^cell! !

!GLMCustomColumn methodsFor: 'accessing' stamp: 'tg 10/22/2009 10:20'!
addRow: aBlockOrSymbol size: anInteger 
	 
	^(self addRow: aBlockOrSymbol) size: anInteger; span: 0! !

!GLMCustomColumn methodsFor: 'accessing' stamp: 'tg 10/22/2009 10:20'!
addRow: aBlockOrSymbol span: anInteger 
	 
	^(self addRow: aBlockOrSymbol) span: anInteger; size: 0! !

!GLMCustomColumn methodsFor: 'testing' stamp: ' 4/5/09 22:18'!
isColumn 
	 
	^true! !

GLMCustomCell subclass: #GLMCustomRow
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Browsers'!

!GLMCustomRow methodsFor: 'accessing' stamp: 'jorge.ressia 6/2/2009 21:49'!
addColumn: aBlockOrSymbol 
	 
	| newColumn cell | 
	cell := aBlockOrSymbol isSymbol 
		ifTrue: 
			[self browser 
				addNewPaneNamed: aBlockOrSymbol. 
			(GLMCustomColumn new) 
				id: aBlockOrSymbol; 
				browser: self browser] 
		ifFalse: 
			[newColumn := GLMCustomColumn new browser: self browser. 
			aBlockOrSymbol value: newColumn. 
			newColumn]. 
	self children addLast: cell. 
	^cell! !

!GLMCustomRow methodsFor: 'accessing' stamp: 'tg 10/22/2009 10:21'!
addColumn: aBlockOrSymbol size: anInteger 
	 
	^(self addColumn: aBlockOrSymbol) size: anInteger; span: 0! !

!GLMCustomRow methodsFor: 'accessing' stamp: 'tg 10/22/2009 10:21'!
addColumn: aBlockOrSymbol span: anInteger 
	 
	^(self addColumn: aBlockOrSymbol) span: anInteger; size: 0! !

!GLMCustomRow methodsFor: 'testing' stamp: ' 4/5/09 22:18'!
isRow 
	 
	^true! !
